cylp: A Python interface for CLP, CBC, and CGL
==============================================

Description
-----------

A Python interface for CLP, CBC, and CGL

License
-------

Eclipse Public License

Upstream Contact
----------------

https://pypi.org/project/cylp/

